@@ -24,6 +24,7 @@ pub enum ExpressionKind {
     Slice,
     Arithmetic,
     Comparison,
+    Contains,
     Like,
     Regex,
     Glob,
@@ -336,6 +337,25 @@ impl Expression for ComparisonExpression {
     }
 }
 
+pub struct ContainsExpression {
+    pub collection: Box<dyn Expression>,
+    pub element: Box<dyn Expression>,
+}
+
+impl Expression for ContainsExpression {
+    fn kind(&self) -> ExpressionKind {
+        ExpressionKind::Contains
+    }
+
+    fn expr_type(&self, _scope: &Environment) -> DataType {
+        DataType::Boolean
+    }
+
+    fn as_any(&self) -> &dyn Any {
+        self
+    }
+}
+
 pub struct LikeExpression {
     pub input: Box<dyn Expression>,
     pub pattern: Box<dyn Expression>,
