@@ -34,6 +34,7 @@ const FIXED_LOGICAL_PLAN: [&str; 8] = [
 pub enum EvaluationResult {
     Do(Value),
     SelectedGroups(GitQLObject, Vec<std::string::String>),
+    SelectedInfo,
     SetGlobalVariable,
 }
 
@@ -73,7 +74,8 @@ fn evaluate_select_query(
     let mut gitql_object = GitQLObject::default();
     let mut alias_table: HashMap<String, String> = query.alias_table;
 
-    let hidden_selections = query.hidden_selections;
+    let hidden_selections_map = query.hidden_selections;
+    let hidden_selections = hidden_selections_map.values().flatten().cloned().collect();
     let mut statements_map = query.statements;
 
     for gql_command in FIXED_LOGICAL_PLAN {
@@ -93,7 +95,7 @@ fn evaluate_select_query(
                         data_provider,
                         &mut gitql_object,
                         &mut alias_table,
-                        &hidden_selections,
+                        &hidden_selections_map,
                     )?;
 
                     // If the main group is empty, no need to perform other statements
@@ -118,13 +120,17 @@ fn evaluate_select_query(
                         data_provider,
                         &mut gitql_object,
                         &mut alias_table,
-                        &hidden_selections,
+                        &hidden_selections_map,
                     )?;
                 }
             }
         }
     }
 
+    // Remove Hidden Selection from the rows after executing the query plan
+    let group: &mut Group = &mut gitql_object.groups[0];
+    remove_hidden_selected(&mut gitql_object.titles, group, &hidden_selections);
+
     // If there are many groups that mean group by is executed before.
     // must merge each group into only one element
     if gitql_object.len() > 1 {
@@ -146,6 +152,21 @@ fn evaluate_select_query(
         }
     }
 
+    // Into statement must be executed last after flatted and remove hidden selections
+    if statements_map.contains_key("into") {
+        let into_statement = statements_map.get_mut("into").unwrap();
+        execute_statement(
+            env,
+            into_statement,
+            data_provider,
+            &mut gitql_object,
+            &mut alias_table,
+            &hidden_selections_map,
+        )?;
+
+        return Ok(EvaluationResult::SelectedInfo);
+    }
+
     // Return the groups and hidden selections to be used later in GUI or TUI ...etc
     Ok(EvaluationResult::SelectedGroups(
         gitql_object,
@@ -209,3 +230,21 @@ fn evaluate_show_tables_query(env: &mut Environment) -> Result<EvaluationResult,
         hidden_selections,
     ))
 }
+
+fn remove_hidden_selected(
+    titles: &mut Vec<String>,
+    group: &mut Group,
+    hidden_selections: &[String],
+) {
+    let titles_count = titles.len();
+    for i in (0..titles_count).rev() {
+        if hidden_selections.contains(&titles[i]) {
+            titles.remove(i);
+            for row in group.rows.iter_mut() {
+                if row.values.len() < i {
+                    row.values.remove(i);
+                }
+            }
+        }
+    }
+}
